@@ -1,3 +1,4 @@
+
 '''
 Holds implementation guts for PyHTCC
 '''
@@ -192,6 +193,26 @@ class Zone:
         raw = self.get_outdoor_temperature_raw()
         return self._get_with_unit(raw)
 
+    def get_indoor_temperature_raw(self) -> int:
+        ''' refreshes the cached zone information then returns the indoor temperature raw value '''
+        self.refresh_zone_info()
+        return self.zone_info['latestData']['uiData']['DispTemperature']
+
+    def get_indoor_temperature(self) -> str:
+        ''' calls get_indoor_temperature_raw() then returns it with a degree sign and the Display unit '''
+        raw = self.get_indoor_temperature_raw()
+        return self._get_with_unit(raw)
+
+    def get_indoor_humidity_raw(self) -> int:
+        ''' refreshes the cached zone information then returns the indoor humidity raw value '''
+        self.refresh_zone_info()
+        return self.zone_info['latestData']['uiData']['IndoorHumidity']
+
+    def get_indoor_humidity(self) -> str:
+        ''' calls get_indoor_humidity_raw() then returns it with a % display unit '''
+        raw = self.get_indoor_humidity_raw()
+        return str(raw) + str("%")
+
     def submit_control_changes(self, data:dict) -> None:
         '''
         This is a low-level API call to PyHTCC.submit_raw_control_changes().
@@ -365,13 +386,13 @@ class PyHTCC:
 
         text_data = result.text
         try:
-            outdoor_temp = int(text_data.split('Control.Model.Property.outdoorTemp,')[1].split(')', 1)[0])
+            outdoor_temp = int(float(text_data.split('Control.Model.Property.outdoorTemp,')[1].split(')', 1)[0].strip()))
         except:
             logger.exception("Unable to find the outdoor temperature.")
             outdoor_temp = None
 
         try:
-            outdoor_humidity = int(text_data.split('Control.Model.Property.outdoorHumidity,')[1].split(')', 1)[0])
+            outdoor_humidity = int(float(text_data.split('Control.Model.Property.outdoorHumidity,')[1].split(')', 1)[0].strip()))
         except:
             logger.exception("Unable to find the outdoor humidity.")
             outdoor_humidity = None
